summaryrefslogtreecommitdiff
path: root/engine/predefs17_2.asm
diff options
context:
space:
mode:
Diffstat (limited to 'engine/predefs17_2.asm')
-rwxr-xr-xengine/predefs17_2.asm10
1 files changed, 5 insertions, 5 deletions
diff --git a/engine/predefs17_2.asm b/engine/predefs17_2.asm
index a1c4ff30..a2dac120 100755
--- a/engine/predefs17_2.asm
+++ b/engine/predefs17_2.asm
@@ -1,10 +1,10 @@
; updates the types of a party mon (pointed to in hl) to the ones of the mon specified in $d11e
SetPartyMonTypes: ; 5db5e (17:5b5e)
- call Load16BitRegisters
- ld bc, W_PARTYMON1_TYPE1 - W_PARTYMON1DATA ; $5
+ call GetPredefRegisters
+ ld bc, wPartyMon1Type - wPartyMon1 ; $5
add hl, bc
- ld a, [$d11e]
- ld [$d0b5], a
+ ld a, [wd11e]
+ ld [wd0b5], a
push hl
call GetMonHeader
pop hl
@@ -1,10 +1,10 @@
-; updates the types of a party mon (pointed to in hl) to the ones of the mon specified in $d11e
+; updates the types of a party mon (pointed to in hl) to the ones of the mon specified in wd11e
SetPartyMonTypes: ; 5db5e (17:5b5e)